@@ -8,7 +8,7 @@ use MooX::Cmd;
 use BioX::Map;
 use Types::Standard qw(Int Str Bool Enum);
 
-our $VERSION = '0.0.8'; # VERSION:
+our $VERSION = '0.0.10'; # VERSION:
 # ABSTRACT: a wrapper for mapping software
 
 
@@ -39,7 +39,7 @@ option indir => (
   format    => 's',
   short     => 'I',
   default   => '',
-  doc       => "path of one fastq file",
+  doc       => "path of indir include fastq file",
 );
 
 
@@ -47,7 +47,7 @@ option outdir => (
   is        => 'ro',
   format    => 's',
   short     => 'O',
-  doc       => "path of one fastq file",
+  doc       => "path of outdir",
   default   => './',
 );
 
@@ -56,7 +56,7 @@ option process_tool => (
   is        => 'ro',
   format    => 'i',
   short     => 'p',
-  doc       => "path of outfile",
+  doc       => "cpu number used by mapping software",
   default   => 1,
 );
 
@@ -65,7 +65,7 @@ option process_sample => (
   is        => 'ro',
   format    => 'i',
   short     => 'P',
-  doc       => "path of outfile",
+  doc       => "number of samples running parallel",
   default   => 1,
 );
 
@@ -126,7 +126,7 @@ BioX::Map::CLIS::Cmd::Map - a wrapper for mapping software
 
 =head1 VERSION
 
-version 0.0.8
+version 0.0.10
 
 =head1 SYNOPSIS
 
@@ -153,7 +153,7 @@ input dir that include multiple samples
 
 =head2 outdir
 
-output dir 
+output dir
 
 =head2 process_tool
 
