@@ -8,7 +8,7 @@ use MooX::Cmd;
 use BioX::Map;
 use Types::Standard qw(Int Str Bool Enum);
 
-our $VERSION = '0.0.8'; # VERSION:
+our $VERSION = '0.0.10'; # VERSION:
 # ABSTRACT: a wrapper for mapping software
 
 
@@ -22,7 +22,7 @@ option indir => (
   format    => 's',
   short     => 'i',
   default   => '',
-  doc       => "path of one fastq file",
+  doc       => "path of indir include fastq files",
 );
 
 
@@ -30,7 +30,7 @@ option outdir => (
   is        => 'ro',
   format    => 's',
   short     => 'o',
-  doc       => "path of one fastq file",
+  doc       => "path of output dir include mapping result",
   default   => './',
 );
 
@@ -39,7 +39,7 @@ option summary_file => (
   is        => 'ro',
   format    => 's',
   short     => 's',
-  doc       => 'path of output file',
+  doc       => 'path of summary file',
   default   => "summary.txt",
 );
 
@@ -48,7 +48,7 @@ option process_tool => (
   is        => 'ro',
   format    => 'i',
   short     => 'p',
-  doc       => "path of outfile",
+  doc       => "cpu number used by soap or bwa",
   default   => 1,
 );
 
@@ -57,7 +57,7 @@ option process_sample => (
   is        => 'ro',
   format    => 'i',
   short     => 'P',
-  doc       => "path of outfile",
+  doc       => "number of samples running parallel",
   default   => 1,
 );
 
@@ -120,7 +120,7 @@ BioX::Map::CLIS::Cmd::MapCompare - a wrapper for mapping software
 
 =head1 VERSION
 
-version 0.0.8
+version 0.0.10
 
 =head1 SYNOPSIS
 
@@ -139,7 +139,7 @@ input dir that include multiple samples
 
 =head2 outdir
 
-output dir 
+output dir
 
 =head2 summary_file
 
